==> openshift-model-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/OAuthAccessTokenListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface OAuthAccessTokenListFluent<A extends OAuthAccessTokenListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,OAuthAccessToken item);
    public A setToItems(int index,OAuthAccessToken item);
    public A addToItems(OAuthAccessToken... items);
    public A addAllToItems(Collection<OAuthAccessToken> items);
    public A removeFromItems(OAuthAccessToken... items);
    public A removeAllFromItems(Collection<OAuthAccessToken> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<OAuthAccessTokenBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<OAuthAccessToken> getItems();
    public List<OAuthAccessToken> buildItems();
    public OAuthAccessToken buildItem(int index);
    public OAuthAccessToken buildFirstItem();
    public OAuthAccessToken buildLastItem();
    public OAuthAccessToken buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OAuthAccessTokenBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OAuthAccessTokenBuilder> predicate);
    public A withItems(List<OAuthAccessToken> items);
    public A withItems(OAuthAccessToken... items);
    public Boolean hasItems();
    public OAuthAccessTokenListFluent.ItemsNested<A> addNewItem();
    public OAuthAccessTokenListFluent.ItemsNested<A> addNewItemLike(OAuthAccessToken item);
    public OAuthAccessTokenListFluent.ItemsNested<A> setNewItemLike(int index,OAuthAccessToken item);
    public OAuthAccessTokenListFluent.ItemsNested<A> editItem(int index);
    public OAuthAccessTokenListFluent.ItemsNested<A> editFirstItem();
    public OAuthAccessTokenListFluent.ItemsNested<A> editLastItem();
    public OAuthAccessTokenListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<OAuthAccessTokenBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OAuthAccessTokenFluent<OAuthAccessTokenListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}

==> openshift-model-5.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/OAuthAccessTokenListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface OAuthAccessTokenListFluent<A extends OAuthAccessTokenListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,OAuthAccessToken item);
    public A setToItems(int index,OAuthAccessToken item);
    public A addToItems(OAuthAccessToken... items);
    public A addAllToItems(Collection<OAuthAccessToken> items);
    public A removeFromItems(OAuthAccessToken... items);
    public A removeAllFromItems(Collection<OAuthAccessToken> items);
    public A removeMatchingFromItems(Predicate<OAuthAccessTokenBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<OAuthAccessToken> getItems();
    public List<OAuthAccessToken> buildItems();
    public OAuthAccessToken buildItem(int index);
    public OAuthAccessToken buildFirstItem();
    public OAuthAccessToken buildLastItem();
    public OAuthAccessToken buildMatchingItem(Predicate<OAuthAccessTokenBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<OAuthAccessTokenBuilder> predicate);
    public A withItems(List<OAuthAccessToken> items);
    public A withItems(OAuthAccessToken... items);
    public Boolean hasItems();
    public OAuthAccessTokenListFluent.ItemsNested<A> addNewItem();
    public OAuthAccessTokenListFluent.ItemsNested<A> addNewItemLike(OAuthAccessToken item);
    public OAuthAccessTokenListFluent.ItemsNested<A> setNewItemLike(int index,OAuthAccessToken item);
    public OAuthAccessTokenListFluent.ItemsNested<A> editItem(int index);
    public OAuthAccessTokenListFluent.ItemsNested<A> editFirstItem();
    public OAuthAccessTokenListFluent.ItemsNested<A> editLastItem();
    public OAuthAccessTokenListFluent.ItemsNested<A> editMatchingItem(Predicate<OAuthAccessTokenBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OAuthAccessTokenFluent<OAuthAccessTokenListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
